def perc(x, y, d=2): 
	calc = round(((1.0 * x/y * 100), d)
	return(calc)
